# MD006 - Consider starting bulleted lists at the beginning of the line

## Description

This rule verifies that top-level unordered list items (bullet points) start at the beginning of the line, without indentation.
Nested list items should be properly indented (typically with 2 or more spaces), but top-level items should not be indented at all.

This rule helps ensure consistent formatting of lists throughout a document, making them easier to read and maintain.
Using proper indentation helps clearly distinguish between top-level list items and their nested child items.

## Configuration

This rule has no configurable options. It always enforces that top-level list items start at the beginning of the line.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
* Item 1
* Item 2
  * Nested item
  * Another nested item
* Item 3
```

In this example, all top-level bullet points (`*`) start at the beginning of the line, and nested items are indented with 2 spaces.

```markdown
* Item 1
  * Nested item
* Item 2

- Another item
  - Nested item
- Final item
```

This example demonstrates consistent formatting with multiple list styles. Top-level bullets start at the beginning of the line regardless of whether `*` or `-` is used.

### Invalid

```markdown
  * Item 1
  * Item 2
    * Nested item
  * Item 3
```

This is invalid because all top-level list items are indented with 2 spaces. The fix would be to remove the indentation:

```markdown
* Item 1
* Item 2
  * Nested item
* Item 3
```

### Fixed

The rule will automatically fix incorrectly indented top-level list items by removing the leading whitespace:

Before:
```markdown
  * Item 1
  * Item 2
    * Nested item
  * Item 3
```

After:
```markdown
* Item 1
* Item 2
    * Nested item
* Item 3
```

## Special Cases

This rule only applies to unordered lists (those marked with `*`, `-`, or `+`). It doesn't apply to ordered lists (marked with numbers).

When multiple lists appear in the same document separated by other content, each list is evaluated independently:

```markdown
* First list item
* Second list item

Some text here

  * Indented list 1  <!-- This is an error -->
  * Indented list 2  <!-- This is an error -->
```
<!-- markdownlint-enable -->

The second list would trigger warnings because the items are indented.

## Related Rules

- [MD005 - List indentation](md005.md): Ensures consistent indentation for list items at the same level.
- [MD004 - Unordered list style](md004.md): Ensures consistent use of list marker style (asterisk, plus, or hyphen).
- [MD007 - Unordered list indentation](md007.md): Verifies that nested list items are indented by a certain number of spaces.
