# MD010 - No Hard Tabs

This rule enforces that there are no hard tabs in the document.

## Description

Hard tabs should not be used for indentation or alignment in Markdown files. Use spaces instead. Hard tabs can display differently in different editors and environments,
leading to inconsistent rendering.

## Configuration

- `code*blocks`: Whether to enforce no hard tabs in code blocks (default: true)
- `spaces*per*tab`: Number of spaces to use when fixing hard tabs (default: 4)

## Examples

<!-- markdownlint-disable -->
### Valid

```markdown
* List item
  * Indented with spaces
    * Deeper indentation
```

### Invalid

```markdown
* List item
  * Indented with tab
    * Deeper indentation
```

### Fixed

```markdown
* List item
  * Indented with spaces
    * Deeper indentation
```
<!-- markdownlint-enable -->

### Special Cases

- When `code*blocks` is false, hard tabs in code blocks are allowed
- Tabs at the beginning of lines are treated as indentation
- Tabs in the middle of lines are treated as alignment
- Empty lines with only tabs are treated as empty lines and should be fixed
- Tabs within HTML comments are ignored and preserved

## Related Rules

- [MD009 - No trailing spaces](md009.md)
- [MD007 - Unordered list indentation](md007.md)
