# MD027 - Multiple Spaces After Blockquote Symbol

## Description

This rule ensures that blockquote markers (`>`) are followed by a single space.  
Multiple spaces after the blockquote symbol can lead to inconsistent rendering and  
are generally considered poor style.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
> This is a properly formatted blockquote.
> Each line starts with a single space after the '>' symbol.
> This ensures consistent formatting.
```

### Invalid

```markdown
>  This blockquote has two spaces after the '>' symbol.
>   This line has three spaces.
>    This line has four spaces.
```

### Fixed

```markdown
> This blockquote has been fixed to have only one space.
> Each line now starts with a single space after the '>' symbol.
> This ensures consistent formatting.
```
<!-- markdownlint-enable -->

## Special Cases

- This rule only applies to blockquotes (lines starting with `>`)
- It does not affect nested blockquotes (e.g., `> > Nested quote`)
- The rule checks for spaces immediately following the blockquote symbol
- It does not affect indentation of the blockquote itself

## Related Rules

- [MD028 - Blank line inside blockquote](md028.md): Ensures proper blockquote structure
- [MD009 - Trailing spaces](md009.md): Checks for trailing whitespace
- [MD010 - Hard tabs](md010.md): Ensures consistent use of spaces instead of tabs
