# MD028 - No Blank Line Inside Blockquote

## Description

This rule ensures that there are no blank lines inside the same blockquote. Blank lines inside a blockquote
break it into multiple blockquotes, which may not be the intended behavior and can lead to inconsistent
rendering across different Markdown processors.

## Configuration

This rule has no configuration options.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
> This is a blockquote
> with multiple lines
> but no blank lines inside.

> This is another blockquote
> that is separated from the first one.
```

### Invalid

```markdown
> This is a blockquote
> with a blank line
>
> inside it, which breaks it into two blockquotes.
```

### Fixed

```markdown
> This is a blockquote
> with multiple lines
> that used to have a blank line
> inside it, but now it's fixed.
```
<!-- markdownlint-enable -->

## Special Cases

- This rule only applies to blank lines within the same blockquote
- It does not affect blank lines between separate blockquotes
- The rule checks for lines that contain only the blockquote symbol (`>`) with no content
- Nested blockquotes are checked separately

## Differences from markdownlint

**Blank lines between blockquotes**: rumdl only flags empty blockquote lines (lines with `>` but no content) that create breaks within blockquotes. markdownlint also flags plain blank lines that separate what it considers to be parts of the same logical blockquote. rumdl's approach is more conservative and avoids false positives where users intentionally separate different blockquotes.

Example that markdownlint flags but rumdl doesn't:
```markdown
> First blockquote

> Second blockquote  ← markdownlint considers this a continuation
```

rumdl treats these as two separate, valid blockquotes, while markdownlint suggests they should be:
```markdown
> First blockquote
>
> Second blockquote
```

## Related Rules

- [MD027 - Multiple spaces after blockquote symbol](md027.md): Ensures proper blockquote formatting
- [MD009 - Trailing spaces](md009.md): Checks for trailing whitespace
- [MD012 - Multiple consecutive blank lines](md012.md): Ensures proper spacing between content
