# MD029 - Ordered List Item Prefix

## Description

This rule ensures that ordered list items use a consistent prefix style. Depending on the configured style,  
list items should either all use the same number (usually 1) or use ascending numbers.

Consistent list formatting improves readability and prevents confusion when lists are rendered.

<!-- markdownlint-disable -->
## Examples

### Valid (ordered style)

```markdown
1. First item
2. Second item
3. Third item
```

### Valid (one style)

```markdown
1. First item
1. Second item
1. Third item
```

### Invalid

```markdown
1. First item
3. Second item
5. Third item
```

### Fixed

```markdown
1. First item
2. Second item
3. Third item
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `style`: The style of ordered list item prefixes to enforce. Can be one of:
  - `"one"`: All items use the number 1 as prefix (default)
  - `"ordered"`: Items use ascending numbers as prefixes
  - `"zero"`: All items use the number 0 as prefix

## Special Cases

- This rule only applies to ordered lists (numbered lists)
- It does not affect unordered lists (bullet points)
- The rule checks the number used in the list item prefix, not the rendered number
- Nested lists are checked separately

## Related Rules

- [MD004 - Unordered list style](md004.md): Similar rule for unordered lists
- [MD005 - Consistent list indentation](md005.md): Ensures proper list indentation
- [MD007 - List indentation](md007.md): Checks for proper indentation of list items
