# MD032 - Lists Should Be Surrounded by Blank Lines

## Description

This rule ensures that lists are surrounded by blank lines. Adding blank lines before and after lists
improves readability and ensures proper rendering across different Markdown processors.

Without blank lines, lists might not be properly recognized as lists, especially when they follow
paragraphs or other content.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
Text before the list.

* Item 1
* Item 2
* Item 3

Text after the list.
```

### Invalid

```markdown
Text before the list.
* Item 1
* Item 2
* Item 3
Text after the list.
```

### Fixed

```markdown
Text before the list.

* Item 1
* Item 2
* Item 3

Text after the list.
```
<!-- markdownlint-enable -->

## Special Cases

- This rule applies to both ordered and unordered lists
- It checks for blank lines both before and after lists
- Lists at the beginning or end of a document only need one blank line (after or before, respectively)
- The rule handles nested lists correctly, requiring blank lines only around the outermost list

## Differences from markdownlint

**Mixed list markers**: rumdl treats consecutive list items with different markers (-, *, +) as a single list with inconsistent markers, flagged by MD004. markdownlint treats them as separate lists requiring blank lines between each marker change. rumdl's approach is more semantically correct as users typically intend this as one list with inconsistent styling.

Example that markdownlint flags but rumdl doesn't:
```markdown
- First item
* Second item  ← markdownlint wants blank line before this
+ Third item   ← markdownlint wants blank line before this
```

## Related Rules

- [MD031 - Fenced code blocks should be surrounded by blank lines](md031.md): Similar rule for code blocks
- [MD022 - Headings should be surrounded by blank lines](md022.md): Ensures proper spacing around headings
- [MD007 - List indentation](md007.md): Checks for proper indentation of list items
- [MD004 - List marker style consistency](md004.md): Handles inconsistent list markers
