# MD045 - Images Should Have Alt Text

## Description

This rule ensures that all images in Markdown have alternative text (alt text). Alt text is important for  
accessibility, as it provides a textual description of an image for screen readers and in cases where  
the image cannot be displayed.

Good alt text should be concise, descriptive, and convey the purpose or content of the image.

<!-- markdownlint-disable -->
## Examples

### Valid

```markdown
![Logo](images/logo.png)

![Company headquarters building](images/headquarters.jpg)

![Chart showing sales growth in 2023](charts/sales-2023.png)
```

### Invalid

```markdown
![](images/cat.jpg)

![ ](diagrams/architecture.png)

![  ](charts/sales-2023.png)
```

### Fixed

```markdown
![Cat playing with yarn](images/cat.jpg)

![System architecture diagram](diagrams/architecture.png)

![Sales growth chart for 2023](charts/sales-2023.png)
```
<!-- markdownlint-enable -->

## Special Cases

- This rule applies to both inline images and reference images
- It checks for empty alt text (square brackets with nothing inside)
- Alt text containing only whitespace is considered empty
- The rule does not check the quality or accuracy of the alt text, only its presence
- The rule does not apply to HTML img tags (use MD033 for that)

## Related Rules

- [MD033 - No inline HTML](md033.md): Ensures no inline HTML is used
- [MD042 - No empty links](md042.md): Similar rule for links
- [MD052 - Reference links should exist](md052.md): Ensures reference links point to valid references
