# MD049 - Emphasis Style

## Description

This rule ensures that emphasis markers (italics) use a consistent style throughout a document.
Markdown supports two styles of emphasis markers: asterisks (`*`) and underscores (`_`).

By default, this rule enforces the use of asterisks for emphasis.

<!-- markdownlint-disable -->
## Examples

### Valid

Consistent use of asterisks (when style is set to "asterisk"):

```markdown
This text has *italic* formatting.

This is another *emphasized* text.
```

### Invalid

Mixed emphasis styles:

```markdown
This text has *italic* formatting.

This is another _emphasized_ text.
```

### Fixed

```markdown
This text has *italic* formatting.

This is another *emphasized* text.
```
<!-- markdownlint-enable -->

## Configuration

This rule has the following configuration options:

- `style`: The style of emphasis markers to enforce. Can be one of:
  - `"consistent"`: Enforce the first emphasis style used in the document (default)
  - `"asterisk"`: Enforce the use of asterisks (`*`)
  - `"underscore"`: Enforce the use of underscores (`_`)

## Special Cases

- This rule only applies to emphasis (italics)
- It does not apply to strong emphasis (bold)
- When style is set to "consistent", the first emphasis style used in the document is enforced
- The rule checks both the opening and closing emphasis markers
- The rule does not apply to code spans or code blocks

## Related Rules

- [MD050 - Strong emphasis style](md050.md): Similar rule for strong emphasis (bold)
- [MD036 - No emphasis as heading](md036.md): Prevents using emphasis instead of proper headings
- [MD037 - No spaces inside emphasis markers](md037.md): Ensures proper formatting of emphasis
