# MD057 - Relative links should point to existing files

This rule checks whether relative links in a Markdown document point to files that actually exist in the file system. It helps identify broken links to other files in your documentation.

## Description

Broken links in documentation are frustrating for users and can undermine trust in your documentation. This rule identifies relative links within Markdown files that point to non-existent files.

The rule only checks relative links (like `[Link](file.md)` or `[Link](../folder/file.md)`), not URLs with protocols (like `https://`, `http://`, `ftp://`, etc.). It also excludes links that are in code blocks or inline code spans.

## Configuration

This rule doesn't have any specific configuration options.

## Examples

<!-- markdownlint-disable MD057 -->

### Invalid

```markdown
[Missing File](does-not-exist.md)

[Missing Directory](missing-folder/file.md)

[Parent Directory Missing](../non-existent-file.md)

[Missing File with Fragment](missing-file.md#section)
```

In the examples above, the linked files don't exist in the file system, so the rule would flag them as issues.

### Valid

```markdown
[Existing File](README.md)

[External Link](https://github.com)

[Email Link](mailto:example@example.com)

[Fragment Only Link](#section-heading)

[Existing File with Fragment](README.md#section)

[Code Block Link](example.md) in a paragraph will be checked, but:

```markdown
[This Link in a Code Block](will-not-be-checked.md)
```

`[This Link in Inline Code](also-not-checked.md)` is also ignored.
```

### Disabling the Rule

You can disable this rule for specific links like this:

```markdown
<!-- markdownlint-disable MD057 -->
[Intentionally Missing Link](not-created-yet.md)
<!-- markdownlint-enable MD057 -->
```

## Special Cases

<!-- markdownlint-disable MD057 -->

- The rule only checks links in the current document's context, so links to anchors within the same document (like `[Link](#section)`) are not checked.
- Links to existing files with fragments (like `[Link](file.md#section)`) only verify that the file exists, not that the fragment is valid. Use rule MD051 to validate fragments.
- Links in code blocks (fenced with ``` or indented) are ignored.
- Links within inline code spans (surrounded by backticks) are ignored.
- External links with protocols are not checked.
- When a rule is disabled for a specific section, links in that section won't be checked.

<!-- markdownlint-enable MD057 -->

## Notes

- This rule can't check links to sections within other files (like `file.md#section`). It only verifies that the file exists.
- The rule doesn't try to fix broken links automatically since creating missing files is beyond the scope of a linter.

## Related Rules

- [MD051 - Link fragments should exist](md051.md): Checks if link fragments (like `#section`) point to existing headings within the document.
- [MD042 - No empty links](md042.md): Checks for links with empty URLs.
- [MD034 - Bare URLs](md034.md): Checks for URLs that are not part of a Markdown link. 